"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ModalView = exports.AvailablePresentationStyles = exports.AvailableBlurEffectStyles = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactNative = require("react-native");
var Helpers = _interopRequireWildcard(require("./functions/helpers"));
var _EventEmitter = require("./functions/EventEmitter");
var _RequestFactory = require("./functions/RequestFactory");
var _Enums = require("./constants/Enums");
var _ModalContext = require("./context/ModalContext");
var _UIManager$componentN, _UIManager$componentN2, _ScrollView$Context;
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
const componentName = "RNIModalView";
const NativeCommands = (_UIManager$componentN = _reactNative.UIManager[componentName]) === null || _UIManager$componentN === void 0 ? void 0 : _UIManager$componentN.Commands;
const NativeConstants = (_UIManager$componentN2 = _reactNative.UIManager[componentName]) === null || _UIManager$componentN2 === void 0 ? void 0 : _UIManager$componentN2.Constants;
const NativeModalView = (0, _reactNative.requireNativeComponent)(componentName);
const AvailableBlurEffectStyles = (NativeConstants === null || NativeConstants === void 0 ? void 0 : NativeConstants.availableBlurEffectStyles) ?? [];
exports.AvailableBlurEffectStyles = AvailableBlurEffectStyles;
const AvailablePresentationStyles = (NativeConstants === null || NativeConstants === void 0 ? void 0 : NativeConstants.availablePresentationStyles) ?? [];
exports.AvailablePresentationStyles = AvailablePresentationStyles;
const NATIVE_PROP_KEYS = {
  // Modal Native Props: Event Callbacks
  onRequestResult: 'onRequestResult',
  onModalBlur: 'onModalBlur',
  onModalFocus: 'onModalFocus',
  onModalShow: 'onModalShow',
  onModalDismiss: 'onModalDismiss',
  onModalDidDismiss: 'onModalDidDismiss',
  onModalWillDismiss: 'onModalWillDismiss',
  onModalAttemptDismiss: 'onModalAttemptDismiss',
  // Modal Native Props: Flags/Booleans
  presentViaMount: 'presentViaMount',
  isModalBGBlurred: 'isModalBGBlurred',
  enableSwipeGesture: 'enableSwipeGesture',
  hideNonVisibleModals: 'hideNonVisibleModals',
  isModalBGTransparent: 'isModalBGTransparent',
  isModalInPresentation: 'isModalInPresentation',
  // Modal Native Props: Strings
  modalID: 'modalID',
  modalTransitionStyle: 'modalTransitionStyle',
  modalPresentationStyle: 'modalPresentationStyle',
  modalBGBlurEffectStyle: 'modalBGBlurEffectStyle'
};
const COMMAND_KEYS = {
  requestModalInfo: 'requestModalInfo',
  requestModalPresentation: 'requestModalPresentation'
};
const VirtualizedListContext = /*#__PURE__*/_react.default.createContext(null);
// fix for react-native 0.60
const hasScrollViewContext = ((_ScrollView$Context = _reactNative.ScrollView.Context) === null || _ScrollView$Context === void 0 ? void 0 : _ScrollView$Context.Provider) != null;
class ModalView extends _react.default.PureComponent {
  constructor(props) {
    var _this;
    super(props);
    _this = this;
    _defineProperty(this, "getEmitterRef", () => {
      return this.emitter;
    });
    _defineProperty(this, "setVisibility", async function (nextVisible) {
      let childProps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      const {
        visible: prevVisible
      } = _this.state;
      const didChange = prevVisible != nextVisible;
      if (!didChange) return false;
      const {
        promise,
        requestID
      } = _RequestFactory.RequestFactory.newRequest(_this, {
        timeout: 2000
      });
      try {
        if (nextVisible) {
          // when showing modal, mount children first,
          await Helpers.setStateAsync(_this, {
            visible: nextVisible,
            // pass down received props to childProps via state
            childProps: Helpers.isObject(childProps) ? childProps : null
          });

          // wait for view to mount
          await new Promise(resolve => {
            _this.didOnLayout = resolve;
          });

          // reset didOnLayout
          _this.didOnLayout = null;
        }
        ;

        // request modal to open/close
        _reactNative.UIManager.dispatchViewManagerCommand((0, _reactNative.findNodeHandle)(_this.nativeModalViewRef), NativeCommands[COMMAND_KEYS.requestModalPresentation], [requestID, nextVisible]);
        const result = await promise;

        // when finish hiding modal, unmount children
        if (!nextVisible) await Helpers.setStateAsync(_this, {
          visible: nextVisible,
          childProps: null
        });
        return result.success;
      } catch (error) {
        _RequestFactory.RequestFactory.rejectRequest(_this, {
          requestID
        });
        console.log("ModalView, setVisibility failed:");
        console.log(error);
        return false;
      }
      ;
    });
    _defineProperty(this, "getModalInfo", async () => {
      const {
        promise,
        requestID
      } = _RequestFactory.RequestFactory.newRequest(this, {
        timeout: 2000
      });
      try {
        // request modal to send modal info
        _reactNative.UIManager.dispatchViewManagerCommand((0, _reactNative.findNodeHandle)(this.nativeModalViewRef), NativeCommands[COMMAND_KEYS.requestModalInfo], [requestID]);
        return await promise;
      } catch (error) {
        _RequestFactory.RequestFactory.rejectRequest(this, {
          requestID
        });
        console.log("ModalView, requestModalInfo failed:");
        console.log(error);
        return false;
      }
      ;
    });
    _defineProperty(this, "setEnableSwipeGesture", async enableSwipeGesture => {
      const {
        enableSwipeGesture: prevVal
      } = this.state;
      if (prevVal != enableSwipeGesture) {
        await Helpers.setStateAsync(this, {
          enableSwipeGesture
        });
      }
      ;
    });
    _defineProperty(this, "setIsModalInPresentation", async isModalInPresentation => {
      const {
        isModalInPresentation: prevVal
      } = this.state;
      if (prevVal != isModalInPresentation) {
        await Helpers.setStateAsync(this, {
          isModalInPresentation
        });
      }
      ;
    });
    _defineProperty(this, "_handleOnLayout", () => {
      const {
        didOnLayout
      } = this;
      didOnLayout && didOnLayout();
    });
    _defineProperty(this, "_handleGetModalRef", () => {
      return this;
    });
    _defineProperty(this, "_handleOnRequestResult", _ref => {
      var _this$props$onRequest, _this$props;
      let {
        nativeEvent
      } = _ref;
      _RequestFactory.RequestFactory.resolveRequestFromObj(this, nativeEvent);
      (_this$props$onRequest = (_this$props = this.props).onRequestResult) === null || _this$props$onRequest === void 0 ? void 0 : _this$props$onRequest.call(_this$props, {
        nativeEvent
      });
    });
    _defineProperty(this, "_handleOnModalBlur", event => {
      var _this$props$onModalBl, _this$props2;
      (_this$props$onModalBl = (_this$props2 = this.props).onModalBlur) === null || _this$props$onModalBl === void 0 ? void 0 : _this$props$onModalBl.call(_this$props2, event);
      this.emitter.emit(_Enums.ModalEventKeys.onModalBlur, event);
    });
    _defineProperty(this, "_handleOnModalFocus", event => {
      var _this$props$onModalFo, _this$props3;
      (_this$props$onModalFo = (_this$props3 = this.props).onModalFocus) === null || _this$props$onModalFo === void 0 ? void 0 : _this$props$onModalFo.call(_this$props3, event);
      this.emitter.emit(_Enums.ModalEventKeys.onModalFocus, event);
    });
    _defineProperty(this, "_handleOnModalShow", event => {
      var _this$props$onModalSh, _this$props4;
      (_this$props$onModalSh = (_this$props4 = this.props).onModalShow) === null || _this$props$onModalSh === void 0 ? void 0 : _this$props$onModalSh.call(_this$props4, event);
      this.emitter.emit(_Enums.ModalEventKeys.onModalShow, event);
    });
    _defineProperty(this, "_handleOnModalDismiss", event => {
      var _this$props$onModalDi, _this$props5;
      (_this$props$onModalDi = (_this$props5 = this.props).onModalDismiss) === null || _this$props$onModalDi === void 0 ? void 0 : _this$props$onModalDi.call(_this$props5, event);
      this.emitter.emit(_Enums.ModalEventKeys.onModalDismiss, event);
      this.setState({
        visible: false,
        childProps: null,
        // reset state values from props
        enableSwipeGesture: this.props.enableSwipeGesture,
        isModalInPresentation: this.props.isModalInPresentation
      });
    });
    _defineProperty(this, "_handleOnModalDidDismiss", event => {
      var _this$props$onModalDi2, _this$props6;
      (_this$props$onModalDi2 = (_this$props6 = this.props).onModalDidDismiss) === null || _this$props$onModalDi2 === void 0 ? void 0 : _this$props$onModalDi2.call(_this$props6, event);
      this.emitter.emit(_Enums.ModalEventKeys.onModalDidDismiss, event);
    });
    _defineProperty(this, "_handleOnModalWillDismiss", event => {
      var _this$props$onModalWi, _this$props7;
      (_this$props$onModalWi = (_this$props7 = this.props).onModalWillDismiss) === null || _this$props$onModalWi === void 0 ? void 0 : _this$props$onModalWi.call(_this$props7, event);
      this.emitter.emit(_Enums.ModalEventKeys.onModalWillDismiss, event);
    });
    _defineProperty(this, "_handleOnModalAttemptDismiss", event => {
      var _this$props$onModalAt, _this$props8;
      (_this$props$onModalAt = (_this$props8 = this.props).onModalAttemptDismiss) === null || _this$props$onModalAt === void 0 ? void 0 : _this$props$onModalAt.call(_this$props8, event);
      this.emitter.emit(_Enums.ModalEventKeys.onModalAttemptDismiss, event);
    });
    _RequestFactory.RequestFactory.initialize(this);
    this.emitter = new _EventEmitter.EventEmitter();
    this._childRef = null;
    this.state = {
      visible: false,
      childProps: null,
      enableSwipeGesture: props.enableSwipeGesture,
      isModalInPresentation: props.isModalInPresentation
    };
  }
  componentWillUnmount() {
    const {
      autoCloseOnUnmount
    } = this.props;
    const {
      visible
    } = this.state;
    if (autoCloseOnUnmount && visible) {
      this.setVisibility(false);
    }
    ;
  }
  // We don't want any responder events bubbling out of the modal.
  _shouldSetResponder() {
    return true;
  }
  //#endregion

  _renderModal() {
    const props = this.props;
    const state = this.state;
    const nativeProps = {
      // pass down props
      ...props,
      // set handlers for native props -------------------------------------------
      [NATIVE_PROP_KEYS.onModalBlur]: this._handleOnModalBlur,
      [NATIVE_PROP_KEYS.onModalFocus]: this._handleOnModalFocus,
      [NATIVE_PROP_KEYS.onModalShow]: this._handleOnModalShow,
      [NATIVE_PROP_KEYS.onModalDismiss]: this._handleOnModalDismiss,
      [NATIVE_PROP_KEYS.onRequestResult]: this._handleOnRequestResult,
      [NATIVE_PROP_KEYS.onModalDidDismiss]: this._handleOnModalDidDismiss,
      [NATIVE_PROP_KEYS.onModalWillDismiss]: this._handleOnModalWillDismiss,
      [NATIVE_PROP_KEYS.onModalAttemptDismiss]: this._handleOnModalAttemptDismiss,
      // optional props ----------------------------
      ...(props.setModalInPresentationFromProps && {
        [NATIVE_PROP_KEYS.isModalInPresentation]: state.isModalInPresentation
      }),
      ...(props.setEnableSwipeGestureFromProps && {
        [NATIVE_PROP_KEYS.enableSwipeGesture]: state.enableSwipeGesture
      })
    };
    return /*#__PURE__*/_react.default.createElement(NativeModalView, _extends({
      ref: r => this.nativeModalViewRef = r,
      style: styles.rootContainer,
      onStartShouldSetResponder: this._shouldSetResponder
    }, nativeProps), state.visible && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      ref: r => this.modalContainerRef = r,
      style: [styles.modalContainer, props.containerStyle],
      collapsable: false,
      onLayout: this._handleOnLayout
    }, /*#__PURE__*/_react.default.cloneElement(props.children, {
      getModalRef: this._handleGetModalRef,
      // pass down props received from setVisibility
      ...(Helpers.isObject(state.childProps) && state.childProps),
      // pass down modalID
      modalID: props[NATIVE_PROP_KEYS.modalID]
    })));
  }
  render() {
    return /*#__PURE__*/_react.default.createElement(_ModalContext.ModalContext.Provider, {
      value: {
        // pass down function to get modal refs
        getModalRef: this._handleGetModalRef,
        getEmitterRef: this.getEmitterRef,
        // pass ref to modal functions -------------------------
        setVisibility: this.setVisibility,
        setEnableSwipeGesture: this.setEnableSwipeGesture,
        setIsModalInPresentation: this.setIsModalInPresentation
      }
    }, /*#__PURE__*/_react.default.createElement(VirtualizedListContext.Provider, {
      value: null
    }, hasScrollViewContext ? /*#__PURE__*/_react.default.createElement(_reactNative.ScrollView.Context.Provider, {
      value: null
    }, this._renderModal()) : this._renderModal()));
  }
}
exports.ModalView = ModalView;
_defineProperty(ModalView, "proptypes", {
  // Props: Events ---------------------
  onRequestResult: _propTypes.default.func,
  onModalBlur: _propTypes.default.func,
  onModalFocus: _propTypes.default.func,
  onModalShow: _propTypes.default.func,
  onModalDismiss: _propTypes.default.func,
  onModalDidDismiss: _propTypes.default.func,
  onModalWillDismiss: _propTypes.default.func,
  onModalAttemptDismiss: _propTypes.default.func,
  // Props: Bool/Flags --------------------------
  presentViaMount: _propTypes.default.bool,
  isModalBGBlurred: _propTypes.default.bool,
  autoCloseOnUnmount: _propTypes.default.bool,
  enableSwipeGesture: _propTypes.default.bool,
  hideNonVisibleModals: _propTypes.default.bool,
  isModalBGTransparent: _propTypes.default.bool,
  isModalInPresentation: _propTypes.default.bool,
  setEnableSwipeGestureFromProps: _propTypes.default.bool,
  setModalInPresentationFromProps: _propTypes.default.bool,
  // Props: String ------------------------
  modalID: _propTypes.default.string,
  modalTransitionStyle: _propTypes.default.string,
  modalPresentationStyle: _propTypes.default.string,
  modalBGBlurEffectStyle: _propTypes.default.string,
  // Props: Style
  containerStyle: _propTypes.default.object
});
_defineProperty(ModalView, "defaultProps", {
  autoCloseOnUnmount: true,
  enableSwipeGesture: true,
  hideNonVisibleModals: false,
  isModalInPresentation: false,
  setEnableSwipeGestureFromProps: false,
  setModalInPresentationFromProps: false
});
;
const styles = _reactNative.StyleSheet.create({
  rootContainer: {
    position: 'absolute',
    width: 0,
    height: 0,
    overflow: 'hidden'
  },
  modalContainer: {
    position: 'absolute'
  }
});
//# sourceMappingURL=ModalView.ios.js.map