import * as Helpers from './helpers';
export class RequestFactory {
  static initialize(that) {
    that.requestID = 1;
    that.requestMap = {};
  }
  static getRequest(that, requestID) {
    return that.requestMap[requestID];
  }
  static newRequest(that, _ref) {
    let {
      timeout = 0
    } = _ref;
    const requestID = that.requestID++;
    const promise = new Promise((resolve, reject) => {
      that.requestMap[requestID] = {
        resolve,
        reject
      };
    });
    return {
      requestID,
      promise: timeout ? Helpers.promiseWithTimeout(timeout, promise) : promise
    };
  }
  static resolveRequest(that, _ref2) {
    let {
      requestID,
      success,
      params
    } = _ref2;
    try {
      const promise = that.requestMap[requestID];
      (success ? promise.resolve : promise.reject)(params);
    } catch (error) {
      console.log("RequestFactory, resolveRequest: failed");
      console.log(error);
    }
    ;
  }
  static resolveRequestFromObj(that, object) {
    try {
      const {
        requestID,
        success = false,
        ...other
      } = object;
      const promise = that.requestMap[requestID];
      (success ? promise.resolve : promise.reject)(other);
    } catch (error) {
      console.log("RequestFactory, resolveRequestFromObj: failed");
      console.log(error);
    }
    ;
  }
  static rejectRequest(that, _ref3) {
    let {
      requestID,
      message = ""
    } = _ref3;
    const promise = that.requestMap[requestID];
    promise.reject(message);
  }
}
;
//# sourceMappingURL=RequestFactory.js.map